margins <-
function (object, ...) {
    UseMethod("margins")
}

